@echo off
setlocal

:: Cài đặt các công cụ cần thiết nếu chưa có
echo --- Kiem tra cac cong cu build... ---
pip install --upgrade build twine

:: Chay script python de thuc hien build va upload
python scripts/publish.py %*

if %ERRORLEVEL% NEQ 0 (
    echo [LOI] Co loi xay ra trong qua trinh phat hanh.
    exit /b %ERRORLEVEL%
)

endlocal
